/****************************************************************************
** Meta object code from reading C++ file 'pointer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwayland-6.7.0/src/client/pointer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pointer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KWayland6Client7PointerE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::Pointer::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client7PointerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::Pointer",
        "entered",
        "",
        "serial",
        "QPointF",
        "relativeToSurface",
        "left",
        "motion",
        "time",
        "buttonStateChanged",
        "button",
        "KWayland::Client::Pointer::ButtonState",
        "state",
        "axisChanged",
        "KWayland::Client::Pointer::Axis",
        "axis",
        "delta",
        "axisSourceChanged",
        "KWayland::Client::Pointer::AxisSource",
        "source",
        "axisDiscreteChanged",
        "discreteDelta",
        "axisStopped",
        "frame"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'entered'
        QtMocHelpers::SignalData<void(quint32, const QPointF &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'left'
        QtMocHelpers::SignalData<void(quint32)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'motion'
        QtMocHelpers::SignalData<void(const QPointF &, quint32)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::UInt, 8 },
        }}),
        // Signal 'buttonStateChanged'
        QtMocHelpers::SignalData<void(quint32, quint32, quint32, KWayland::Client::Pointer::ButtonState)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 8 }, { QMetaType::UInt, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisChanged'
        QtMocHelpers::SignalData<void(quint32, KWayland::Client::Pointer::Axis, qreal)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 8 }, { 0x80000000 | 14, 15 }, { QMetaType::QReal, 16 },
        }}),
        // Signal 'axisSourceChanged'
        QtMocHelpers::SignalData<void(KWayland::Client::Pointer::AxisSource)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'axisDiscreteChanged'
        QtMocHelpers::SignalData<void(KWayland::Client::Pointer::Axis, qint32)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Int, 21 },
        }}),
        // Signal 'axisStopped'
        QtMocHelpers::SignalData<void(quint32, KWayland::Client::Pointer::Axis)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 8 }, { 0x80000000 | 14, 15 },
        }}),
        // Signal 'frame'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Pointer, qt_meta_tag_ZN8KWayland6Client7PointerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::Pointer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client7PointerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client7PointerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client7PointerE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::Pointer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Pointer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->entered((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 1: _t->left((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 2: _t->motion((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 3: _t->buttonStateChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KWayland::Client::Pointer::ButtonState>>(_a[4]))); break;
        case 4: _t->axisChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KWayland::Client::Pointer::Axis>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 5: _t->axisSourceChanged((*reinterpret_cast<std::add_pointer_t<KWayland::Client::Pointer::AxisSource>>(_a[1]))); break;
        case 6: _t->axisDiscreteChanged((*reinterpret_cast<std::add_pointer_t<KWayland::Client::Pointer::Axis>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 7: _t->axisStopped((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KWayland::Client::Pointer::Axis>>(_a[2]))); break;
        case 8: _t->frame(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWayland::Client::Pointer::ButtonState >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWayland::Client::Pointer::Axis >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWayland::Client::Pointer::AxisSource >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWayland::Client::Pointer::Axis >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWayland::Client::Pointer::Axis >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Pointer::*)(quint32 , const QPointF & )>(_a, &Pointer::entered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Pointer::*)(quint32 )>(_a, &Pointer::left, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Pointer::*)(const QPointF & , quint32 )>(_a, &Pointer::motion, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Pointer::*)(quint32 , quint32 , quint32 , KWayland::Client::Pointer::ButtonState )>(_a, &Pointer::buttonStateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Pointer::*)(quint32 , KWayland::Client::Pointer::Axis , qreal )>(_a, &Pointer::axisChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Pointer::*)(KWayland::Client::Pointer::AxisSource )>(_a, &Pointer::axisSourceChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Pointer::*)(KWayland::Client::Pointer::Axis , qint32 )>(_a, &Pointer::axisDiscreteChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Pointer::*)(quint32 , KWayland::Client::Pointer::Axis )>(_a, &Pointer::axisStopped, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Pointer::*)()>(_a, &Pointer::frame, 8))
            return;
    }
}

const QMetaObject *KWayland::Client::Pointer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::Pointer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client7PointerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::Pointer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::Pointer::entered(quint32 _t1, const QPointF & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KWayland::Client::Pointer::left(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KWayland::Client::Pointer::motion(const QPointF & _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KWayland::Client::Pointer::buttonStateChanged(quint32 _t1, quint32 _t2, quint32 _t3, KWayland::Client::Pointer::ButtonState _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 4
void KWayland::Client::Pointer::axisChanged(quint32 _t1, KWayland::Client::Pointer::Axis _t2, qreal _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void KWayland::Client::Pointer::axisSourceChanged(KWayland::Client::Pointer::AxisSource _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KWayland::Client::Pointer::axisDiscreteChanged(KWayland::Client::Pointer::Axis _t1, qint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void KWayland::Client::Pointer::axisStopped(quint32 _t1, KWayland::Client::Pointer::Axis _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void KWayland::Client::Pointer::frame()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
