/****************************************************************************
** Meta object code from reading C++ file 'registry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwayland-6.7.0/src/client/registry.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'registry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KWayland6Client8RegistryE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::Registry::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client8RegistryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::Registry",
        "compositorAnnounced",
        "",
        "name",
        "version",
        "shellAnnounced",
        "seatAnnounced",
        "shmAnnounced",
        "subCompositorAnnounced",
        "outputAnnounced",
        "dataDeviceManagerAnnounced",
        "plasmaShellAnnounced",
        "plasmaActivationFeedbackAnnounced",
        "plasmaVirtualDesktopManagementAnnounced",
        "plasmaWindowManagementAnnounced",
        "fakeInputAnnounced",
        "shadowAnnounced",
        "blurAnnounced",
        "contrastAnnounced",
        "slideAnnounced",
        "dpmsAnnounced",
        "textInputManagerUnstableV0Announced",
        "textInputManagerUnstableV2Announced",
        "xdgShellUnstableV5Announced",
        "xdgShellUnstableV6Announced",
        "relativePointerManagerUnstableV1Announced",
        "pointerGesturesUnstableV1Announced",
        "pointerConstraintsUnstableV1Announced",
        "exporterUnstableV2Announced",
        "importerUnstableV2Announced",
        "idleInhibitManagerUnstableV1Announced",
        "appMenuAnnounced",
        "xdgOutputAnnounced",
        "xdgShellStableAnnounced",
        "xdgDecorationAnnounced",
        "compositorRemoved",
        "shellRemoved",
        "seatRemoved",
        "shmRemoved",
        "subCompositorRemoved",
        "outputRemoved",
        "dataDeviceManagerRemoved",
        "plasmaShellRemoved",
        "plasmaActivationFeedbackRemoved",
        "plasmaVirtualDesktopManagementRemoved",
        "plasmaWindowManagementRemoved",
        "fakeInputRemoved",
        "shadowRemoved",
        "blurRemoved",
        "contrastRemoved",
        "slideRemoved",
        "dpmsRemoved",
        "textInputManagerUnstableV0Removed",
        "textInputManagerUnstableV2Removed",
        "xdgShellUnstableV5Removed",
        "xdgShellUnstableV6Removed",
        "relativePointerManagerUnstableV1Removed",
        "pointerGesturesUnstableV1Removed",
        "pointerConstraintsUnstableV1Removed",
        "exporterUnstableV2Removed",
        "importerUnstableV2Removed",
        "idleInhibitManagerUnstableV1Removed",
        "appMenuRemoved",
        "xdgOutputRemoved",
        "xdgShellStableRemoved",
        "xdgDecorationRemoved",
        "interfaceAnnounced",
        "interface",
        "interfaceRemoved",
        "interfacesAnnounced",
        "registryDestroyed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'compositorAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'shellAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'seatAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'shmAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'subCompositorAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'outputAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'dataDeviceManagerAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'plasmaShellAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'plasmaActivationFeedbackAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'plasmaVirtualDesktopManagementAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'plasmaWindowManagementAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'fakeInputAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'shadowAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'blurAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'contrastAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'slideAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'dpmsAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'textInputManagerUnstableV0Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'textInputManagerUnstableV2Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'xdgShellUnstableV5Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'xdgShellUnstableV6Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'relativePointerManagerUnstableV1Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'pointerGesturesUnstableV1Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'pointerConstraintsUnstableV1Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'exporterUnstableV2Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'importerUnstableV2Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'idleInhibitManagerUnstableV1Announced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'appMenuAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'xdgOutputAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'xdgShellStableAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'xdgDecorationAnnounced'
        QtMocHelpers::SignalData<void(quint32, quint32)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'compositorRemoved'
        QtMocHelpers::SignalData<void(quint32)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'shellRemoved'
        QtMocHelpers::SignalData<void(quint32)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'seatRemoved'
        QtMocHelpers::SignalData<void(quint32)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'shmRemoved'
        QtMocHelpers::SignalData<void(quint32)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'subCompositorRemoved'
        QtMocHelpers::SignalData<void(quint32)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'outputRemoved'
        QtMocHelpers::SignalData<void(quint32)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'dataDeviceManagerRemoved'
        QtMocHelpers::SignalData<void(quint32)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'plasmaShellRemoved'
        QtMocHelpers::SignalData<void(quint32)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'plasmaActivationFeedbackRemoved'
        QtMocHelpers::SignalData<void(quint32)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'plasmaVirtualDesktopManagementRemoved'
        QtMocHelpers::SignalData<void(quint32)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'plasmaWindowManagementRemoved'
        QtMocHelpers::SignalData<void(quint32)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'fakeInputRemoved'
        QtMocHelpers::SignalData<void(quint32)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'shadowRemoved'
        QtMocHelpers::SignalData<void(quint32)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'blurRemoved'
        QtMocHelpers::SignalData<void(quint32)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'contrastRemoved'
        QtMocHelpers::SignalData<void(quint32)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'slideRemoved'
        QtMocHelpers::SignalData<void(quint32)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'dpmsRemoved'
        QtMocHelpers::SignalData<void(quint32)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'textInputManagerUnstableV0Removed'
        QtMocHelpers::SignalData<void(quint32)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'textInputManagerUnstableV2Removed'
        QtMocHelpers::SignalData<void(quint32)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'xdgShellUnstableV5Removed'
        QtMocHelpers::SignalData<void(quint32)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'xdgShellUnstableV6Removed'
        QtMocHelpers::SignalData<void(quint32)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'relativePointerManagerUnstableV1Removed'
        QtMocHelpers::SignalData<void(quint32)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'pointerGesturesUnstableV1Removed'
        QtMocHelpers::SignalData<void(quint32)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'pointerConstraintsUnstableV1Removed'
        QtMocHelpers::SignalData<void(quint32)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'exporterUnstableV2Removed'
        QtMocHelpers::SignalData<void(quint32)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'importerUnstableV2Removed'
        QtMocHelpers::SignalData<void(quint32)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'idleInhibitManagerUnstableV1Removed'
        QtMocHelpers::SignalData<void(quint32)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'appMenuRemoved'
        QtMocHelpers::SignalData<void(quint32)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'xdgOutputRemoved'
        QtMocHelpers::SignalData<void(quint32)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'xdgShellStableRemoved'
        QtMocHelpers::SignalData<void(quint32)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'xdgDecorationRemoved'
        QtMocHelpers::SignalData<void(quint32)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'interfaceAnnounced'
        QtMocHelpers::SignalData<void(QByteArray, quint32, quint32)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 67 }, { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'interfaceRemoved'
        QtMocHelpers::SignalData<void(quint32)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'interfacesAnnounced'
        QtMocHelpers::SignalData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'registryDestroyed'
        QtMocHelpers::SignalData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Registry, qt_meta_tag_ZN8KWayland6Client8RegistryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::Registry::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client8RegistryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client8RegistryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client8RegistryE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::Registry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Registry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->compositorAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 1: _t->shellAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 2: _t->seatAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 3: _t->shmAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 4: _t->subCompositorAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 5: _t->outputAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 6: _t->dataDeviceManagerAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 7: _t->plasmaShellAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 8: _t->plasmaActivationFeedbackAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 9: _t->plasmaVirtualDesktopManagementAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 10: _t->plasmaWindowManagementAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 11: _t->fakeInputAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 12: _t->shadowAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 13: _t->blurAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 14: _t->contrastAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 15: _t->slideAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 16: _t->dpmsAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 17: _t->textInputManagerUnstableV0Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 18: _t->textInputManagerUnstableV2Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 19: _t->xdgShellUnstableV5Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 20: _t->xdgShellUnstableV6Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 21: _t->relativePointerManagerUnstableV1Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 22: _t->pointerGesturesUnstableV1Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 23: _t->pointerConstraintsUnstableV1Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 24: _t->exporterUnstableV2Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 25: _t->importerUnstableV2Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 26: _t->idleInhibitManagerUnstableV1Announced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 27: _t->appMenuAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 28: _t->xdgOutputAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 29: _t->xdgShellStableAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 30: _t->xdgDecorationAnnounced((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 31: _t->compositorRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 32: _t->shellRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 33: _t->seatRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 34: _t->shmRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 35: _t->subCompositorRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 36: _t->outputRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 37: _t->dataDeviceManagerRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 38: _t->plasmaShellRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 39: _t->plasmaActivationFeedbackRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 40: _t->plasmaVirtualDesktopManagementRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 41: _t->plasmaWindowManagementRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 42: _t->fakeInputRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 43: _t->shadowRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 44: _t->blurRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 45: _t->contrastRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 46: _t->slideRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 47: _t->dpmsRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 48: _t->textInputManagerUnstableV0Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 49: _t->textInputManagerUnstableV2Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 50: _t->xdgShellUnstableV5Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 51: _t->xdgShellUnstableV6Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 52: _t->relativePointerManagerUnstableV1Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 53: _t->pointerGesturesUnstableV1Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 54: _t->pointerConstraintsUnstableV1Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 55: _t->exporterUnstableV2Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 56: _t->importerUnstableV2Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 57: _t->idleInhibitManagerUnstableV1Removed((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 58: _t->appMenuRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 59: _t->xdgOutputRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 60: _t->xdgShellStableRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 61: _t->xdgDecorationRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 62: _t->interfaceAnnounced((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[3]))); break;
        case 63: _t->interfaceRemoved((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 64: _t->interfacesAnnounced(); break;
        case 65: _t->registryDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::compositorAnnounced, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::shellAnnounced, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::seatAnnounced, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::shmAnnounced, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::subCompositorAnnounced, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::outputAnnounced, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::dataDeviceManagerAnnounced, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::plasmaShellAnnounced, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::plasmaActivationFeedbackAnnounced, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::plasmaVirtualDesktopManagementAnnounced, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::plasmaWindowManagementAnnounced, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::fakeInputAnnounced, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::shadowAnnounced, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::blurAnnounced, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::contrastAnnounced, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::slideAnnounced, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::dpmsAnnounced, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::textInputManagerUnstableV0Announced, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::textInputManagerUnstableV2Announced, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::xdgShellUnstableV5Announced, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::xdgShellUnstableV6Announced, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::relativePointerManagerUnstableV1Announced, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::pointerGesturesUnstableV1Announced, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::pointerConstraintsUnstableV1Announced, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::exporterUnstableV2Announced, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::importerUnstableV2Announced, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::idleInhibitManagerUnstableV1Announced, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::appMenuAnnounced, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::xdgOutputAnnounced, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::xdgShellStableAnnounced, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 , quint32 )>(_a, &Registry::xdgDecorationAnnounced, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::compositorRemoved, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::shellRemoved, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::seatRemoved, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::shmRemoved, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::subCompositorRemoved, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::outputRemoved, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::dataDeviceManagerRemoved, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::plasmaShellRemoved, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::plasmaActivationFeedbackRemoved, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::plasmaVirtualDesktopManagementRemoved, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::plasmaWindowManagementRemoved, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::fakeInputRemoved, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::shadowRemoved, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::blurRemoved, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::contrastRemoved, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::slideRemoved, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::dpmsRemoved, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::textInputManagerUnstableV0Removed, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::textInputManagerUnstableV2Removed, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::xdgShellUnstableV5Removed, 50))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::xdgShellUnstableV6Removed, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::relativePointerManagerUnstableV1Removed, 52))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::pointerGesturesUnstableV1Removed, 53))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::pointerConstraintsUnstableV1Removed, 54))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::exporterUnstableV2Removed, 55))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::importerUnstableV2Removed, 56))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::idleInhibitManagerUnstableV1Removed, 57))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::appMenuRemoved, 58))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::xdgOutputRemoved, 59))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::xdgShellStableRemoved, 60))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::xdgDecorationRemoved, 61))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(QByteArray , quint32 , quint32 )>(_a, &Registry::interfaceAnnounced, 62))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(quint32 )>(_a, &Registry::interfaceRemoved, 63))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)()>(_a, &Registry::interfacesAnnounced, 64))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)()>(_a, &Registry::registryDestroyed, 65))
            return;
    }
}

const QMetaObject *KWayland::Client::Registry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::Registry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client8RegistryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::Registry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 66)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 66;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 66)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 66;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::Registry::compositorAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KWayland::Client::Registry::shellAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KWayland::Client::Registry::seatAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KWayland::Client::Registry::shmAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KWayland::Client::Registry::subCompositorAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KWayland::Client::Registry::outputAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KWayland::Client::Registry::dataDeviceManagerAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void KWayland::Client::Registry::plasmaShellAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void KWayland::Client::Registry::plasmaActivationFeedbackAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void KWayland::Client::Registry::plasmaVirtualDesktopManagementAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void KWayland::Client::Registry::plasmaWindowManagementAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void KWayland::Client::Registry::fakeInputAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void KWayland::Client::Registry::shadowAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void KWayland::Client::Registry::blurAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void KWayland::Client::Registry::contrastAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void KWayland::Client::Registry::slideAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void KWayland::Client::Registry::dpmsAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}

// SIGNAL 17
void KWayland::Client::Registry::textInputManagerUnstableV0Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void KWayland::Client::Registry::textInputManagerUnstableV2Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2);
}

// SIGNAL 19
void KWayland::Client::Registry::xdgShellUnstableV5Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void KWayland::Client::Registry::xdgShellUnstableV6Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2);
}

// SIGNAL 21
void KWayland::Client::Registry::relativePointerManagerUnstableV1Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2);
}

// SIGNAL 22
void KWayland::Client::Registry::pointerGesturesUnstableV1Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2);
}

// SIGNAL 23
void KWayland::Client::Registry::pointerConstraintsUnstableV1Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2);
}

// SIGNAL 24
void KWayland::Client::Registry::exporterUnstableV2Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1, _t2);
}

// SIGNAL 25
void KWayland::Client::Registry::importerUnstableV2Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2);
}

// SIGNAL 26
void KWayland::Client::Registry::idleInhibitManagerUnstableV1Announced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2);
}

// SIGNAL 27
void KWayland::Client::Registry::appMenuAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2);
}

// SIGNAL 28
void KWayland::Client::Registry::xdgOutputAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1, _t2);
}

// SIGNAL 29
void KWayland::Client::Registry::xdgShellStableAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1, _t2);
}

// SIGNAL 30
void KWayland::Client::Registry::xdgDecorationAnnounced(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1, _t2);
}

// SIGNAL 31
void KWayland::Client::Registry::compositorRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void KWayland::Client::Registry::shellRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void KWayland::Client::Registry::seatRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1);
}

// SIGNAL 34
void KWayland::Client::Registry::shmRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 34, nullptr, _t1);
}

// SIGNAL 35
void KWayland::Client::Registry::subCompositorRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1);
}

// SIGNAL 36
void KWayland::Client::Registry::outputRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1);
}

// SIGNAL 37
void KWayland::Client::Registry::dataDeviceManagerRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 37, nullptr, _t1);
}

// SIGNAL 38
void KWayland::Client::Registry::plasmaShellRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 38, nullptr, _t1);
}

// SIGNAL 39
void KWayland::Client::Registry::plasmaActivationFeedbackRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1);
}

// SIGNAL 40
void KWayland::Client::Registry::plasmaVirtualDesktopManagementRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 40, nullptr, _t1);
}

// SIGNAL 41
void KWayland::Client::Registry::plasmaWindowManagementRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 41, nullptr, _t1);
}

// SIGNAL 42
void KWayland::Client::Registry::fakeInputRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 42, nullptr, _t1);
}

// SIGNAL 43
void KWayland::Client::Registry::shadowRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 43, nullptr, _t1);
}

// SIGNAL 44
void KWayland::Client::Registry::blurRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 44, nullptr, _t1);
}

// SIGNAL 45
void KWayland::Client::Registry::contrastRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 45, nullptr, _t1);
}

// SIGNAL 46
void KWayland::Client::Registry::slideRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 46, nullptr, _t1);
}

// SIGNAL 47
void KWayland::Client::Registry::dpmsRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 47, nullptr, _t1);
}

// SIGNAL 48
void KWayland::Client::Registry::textInputManagerUnstableV0Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 48, nullptr, _t1);
}

// SIGNAL 49
void KWayland::Client::Registry::textInputManagerUnstableV2Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 49, nullptr, _t1);
}

// SIGNAL 50
void KWayland::Client::Registry::xdgShellUnstableV5Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 50, nullptr, _t1);
}

// SIGNAL 51
void KWayland::Client::Registry::xdgShellUnstableV6Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 51, nullptr, _t1);
}

// SIGNAL 52
void KWayland::Client::Registry::relativePointerManagerUnstableV1Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 52, nullptr, _t1);
}

// SIGNAL 53
void KWayland::Client::Registry::pointerGesturesUnstableV1Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 53, nullptr, _t1);
}

// SIGNAL 54
void KWayland::Client::Registry::pointerConstraintsUnstableV1Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 54, nullptr, _t1);
}

// SIGNAL 55
void KWayland::Client::Registry::exporterUnstableV2Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 55, nullptr, _t1);
}

// SIGNAL 56
void KWayland::Client::Registry::importerUnstableV2Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 56, nullptr, _t1);
}

// SIGNAL 57
void KWayland::Client::Registry::idleInhibitManagerUnstableV1Removed(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 57, nullptr, _t1);
}

// SIGNAL 58
void KWayland::Client::Registry::appMenuRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 58, nullptr, _t1);
}

// SIGNAL 59
void KWayland::Client::Registry::xdgOutputRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 59, nullptr, _t1);
}

// SIGNAL 60
void KWayland::Client::Registry::xdgShellStableRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 60, nullptr, _t1);
}

// SIGNAL 61
void KWayland::Client::Registry::xdgDecorationRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 61, nullptr, _t1);
}

// SIGNAL 62
void KWayland::Client::Registry::interfaceAnnounced(QByteArray _t1, quint32 _t2, quint32 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 62, nullptr, _t1, _t2, _t3);
}

// SIGNAL 63
void KWayland::Client::Registry::interfaceRemoved(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 63, nullptr, _t1);
}

// SIGNAL 64
void KWayland::Client::Registry::interfacesAnnounced()
{
    QMetaObject::activate(this, &staticMetaObject, 64, nullptr);
}

// SIGNAL 65
void KWayland::Client::Registry::registryDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 65, nullptr);
}
QT_WARNING_POP
