/****************************************************************************
** Meta object code from reading C++ file 'plasmavirtualdesktop.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwayland-6.7.0/src/client/plasmavirtualdesktop.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasmavirtualdesktop.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KWayland6Client30PlasmaVirtualDesktopManagementE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PlasmaVirtualDesktopManagement::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client30PlasmaVirtualDesktopManagementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PlasmaVirtualDesktopManagement",
        "removed",
        "",
        "desktopCreated",
        "id",
        "position",
        "desktopRemoved",
        "rowsChanged",
        "rows",
        "done"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopCreated'
        QtMocHelpers::SignalData<void(const QString &, quint32)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::UInt, 5 },
        }}),
        // Signal 'desktopRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'rowsChanged'
        QtMocHelpers::SignalData<void(quint32)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 8 },
        }}),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlasmaVirtualDesktopManagement, qt_meta_tag_ZN8KWayland6Client30PlasmaVirtualDesktopManagementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PlasmaVirtualDesktopManagement::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client30PlasmaVirtualDesktopManagementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client30PlasmaVirtualDesktopManagementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client30PlasmaVirtualDesktopManagementE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PlasmaVirtualDesktopManagement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaVirtualDesktopManagement *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->removed(); break;
        case 1: _t->desktopCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 2: _t->desktopRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->rowsChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 4: _t->done(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktopManagement::*)()>(_a, &PlasmaVirtualDesktopManagement::removed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktopManagement::*)(const QString & , quint32 )>(_a, &PlasmaVirtualDesktopManagement::desktopCreated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktopManagement::*)(const QString & )>(_a, &PlasmaVirtualDesktopManagement::desktopRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktopManagement::*)(quint32 )>(_a, &PlasmaVirtualDesktopManagement::rowsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktopManagement::*)()>(_a, &PlasmaVirtualDesktopManagement::done, 4))
            return;
    }
}

const QMetaObject *KWayland::Client::PlasmaVirtualDesktopManagement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PlasmaVirtualDesktopManagement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client30PlasmaVirtualDesktopManagementE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::PlasmaVirtualDesktopManagement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::PlasmaVirtualDesktopManagement::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWayland::Client::PlasmaVirtualDesktopManagement::desktopCreated(const QString & _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KWayland::Client::PlasmaVirtualDesktopManagement::desktopRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KWayland::Client::PlasmaVirtualDesktopManagement::rowsChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KWayland::Client::PlasmaVirtualDesktopManagement::done()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client20PlasmaVirtualDesktopE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PlasmaVirtualDesktop::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client20PlasmaVirtualDesktopE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PlasmaVirtualDesktop",
        "activated",
        "",
        "deactivated",
        "positionChanged",
        "position",
        "outputEntered",
        "outputName",
        "done",
        "removed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deactivated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(quint32)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Signal 'outputEntered'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlasmaVirtualDesktop, qt_meta_tag_ZN8KWayland6Client20PlasmaVirtualDesktopE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PlasmaVirtualDesktop::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client20PlasmaVirtualDesktopE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client20PlasmaVirtualDesktopE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client20PlasmaVirtualDesktopE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PlasmaVirtualDesktop::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaVirtualDesktop *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activated(); break;
        case 1: _t->deactivated(); break;
        case 2: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 3: _t->outputEntered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->done(); break;
        case 5: _t->removed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktop::*)()>(_a, &PlasmaVirtualDesktop::activated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktop::*)()>(_a, &PlasmaVirtualDesktop::deactivated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktop::*)(quint32 )>(_a, &PlasmaVirtualDesktop::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktop::*)(const QString & )>(_a, &PlasmaVirtualDesktop::outputEntered, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktop::*)()>(_a, &PlasmaVirtualDesktop::done, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaVirtualDesktop::*)()>(_a, &PlasmaVirtualDesktop::removed, 5))
            return;
    }
}

const QMetaObject *KWayland::Client::PlasmaVirtualDesktop::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PlasmaVirtualDesktop::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client20PlasmaVirtualDesktopE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::PlasmaVirtualDesktop::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::PlasmaVirtualDesktop::activated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWayland::Client::PlasmaVirtualDesktop::deactivated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWayland::Client::PlasmaVirtualDesktop::positionChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KWayland::Client::PlasmaVirtualDesktop::outputEntered(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KWayland::Client::PlasmaVirtualDesktop::done()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KWayland::Client::PlasmaVirtualDesktop::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
