/****************************************************************************
** Meta object code from reading C++ file 'pointergestures.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwayland-6.7.0/src/client/pointergestures.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pointergestures.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KWayland6Client15PointerGesturesE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PointerGestures::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client15PointerGesturesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PointerGestures",
        "removed",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PointerGestures, qt_meta_tag_ZN8KWayland6Client15PointerGesturesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PointerGestures::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client15PointerGesturesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client15PointerGesturesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client15PointerGesturesE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PointerGestures::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PointerGestures *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->removed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PointerGestures::*)()>(_a, &PointerGestures::removed, 0))
            return;
    }
}

const QMetaObject *KWayland::Client::PointerGestures::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PointerGestures::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client15PointerGesturesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::PointerGestures::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::PointerGestures::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client19PointerSwipeGestureE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PointerSwipeGesture::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client19PointerSwipeGestureE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PointerSwipeGesture",
        "started",
        "",
        "serial",
        "time",
        "updated",
        "QSizeF",
        "delta",
        "ended",
        "cancelled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void(quint32, quint32)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'updated'
        QtMocHelpers::SignalData<void(const QSizeF &, quint32)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'ended'
        QtMocHelpers::SignalData<void(quint32, quint32)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'cancelled'
        QtMocHelpers::SignalData<void(quint32, quint32)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PointerSwipeGesture, qt_meta_tag_ZN8KWayland6Client19PointerSwipeGestureE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PointerSwipeGesture::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client19PointerSwipeGestureE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client19PointerSwipeGestureE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client19PointerSwipeGestureE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PointerSwipeGesture::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PointerSwipeGesture *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 1: _t->updated((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 2: _t->ended((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 3: _t->cancelled((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PointerSwipeGesture::*)(quint32 , quint32 )>(_a, &PointerSwipeGesture::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerSwipeGesture::*)(const QSizeF & , quint32 )>(_a, &PointerSwipeGesture::updated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerSwipeGesture::*)(quint32 , quint32 )>(_a, &PointerSwipeGesture::ended, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerSwipeGesture::*)(quint32 , quint32 )>(_a, &PointerSwipeGesture::cancelled, 3))
            return;
    }
}

const QMetaObject *KWayland::Client::PointerSwipeGesture::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PointerSwipeGesture::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client19PointerSwipeGestureE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::PointerSwipeGesture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::PointerSwipeGesture::started(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KWayland::Client::PointerSwipeGesture::updated(const QSizeF & _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KWayland::Client::PointerSwipeGesture::ended(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KWayland::Client::PointerSwipeGesture::cancelled(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client19PointerPinchGestureE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PointerPinchGesture::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client19PointerPinchGestureE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PointerPinchGesture",
        "started",
        "",
        "serial",
        "time",
        "updated",
        "QSizeF",
        "delta",
        "scale",
        "rotation",
        "ended",
        "cancelled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void(quint32, quint32)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'updated'
        QtMocHelpers::SignalData<void(const QSizeF &, qreal, qreal, quint32)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QReal, 8 }, { QMetaType::QReal, 9 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'ended'
        QtMocHelpers::SignalData<void(quint32, quint32)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'cancelled'
        QtMocHelpers::SignalData<void(quint32, quint32)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PointerPinchGesture, qt_meta_tag_ZN8KWayland6Client19PointerPinchGestureE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PointerPinchGesture::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client19PointerPinchGestureE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client19PointerPinchGestureE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client19PointerPinchGestureE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PointerPinchGesture::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PointerPinchGesture *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 1: _t->updated((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[4]))); break;
        case 2: _t->ended((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 3: _t->cancelled((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PointerPinchGesture::*)(quint32 , quint32 )>(_a, &PointerPinchGesture::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerPinchGesture::*)(const QSizeF & , qreal , qreal , quint32 )>(_a, &PointerPinchGesture::updated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerPinchGesture::*)(quint32 , quint32 )>(_a, &PointerPinchGesture::ended, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerPinchGesture::*)(quint32 , quint32 )>(_a, &PointerPinchGesture::cancelled, 3))
            return;
    }
}

const QMetaObject *KWayland::Client::PointerPinchGesture::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PointerPinchGesture::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client19PointerPinchGestureE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::PointerPinchGesture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::PointerPinchGesture::started(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KWayland::Client::PointerPinchGesture::updated(const QSizeF & _t1, qreal _t2, qreal _t3, quint32 _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void KWayland::Client::PointerPinchGesture::ended(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KWayland::Client::PointerPinchGesture::cancelled(quint32 _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
