/****************************************************************************
** Meta object code from reading C++ file 'xdgshell.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwayland-6.7.0/src/client/xdgshell.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xdgshell.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KWayland6Client8XdgShellE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::XdgShell::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client8XdgShellE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::XdgShell",
        "removed",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgShell, qt_meta_tag_ZN8KWayland6Client8XdgShellE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::XdgShell::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client8XdgShellE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client8XdgShellE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client8XdgShellE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::XdgShell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgShell *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->removed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XdgShell::*)()>(_a, &XdgShell::removed, 0))
            return;
    }
}

const QMetaObject *KWayland::Client::XdgShell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::XdgShell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client8XdgShellE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::XdgShell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::XdgShell::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client15XdgShellSurfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::XdgShellSurface::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client15XdgShellSurfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::XdgShellSurface",
        "closeRequested",
        "",
        "configureRequested",
        "QSize",
        "size",
        "KWayland::Client::XdgShellSurface::States",
        "states",
        "serial",
        "sizeChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'closeRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configureRequested'
        QtMocHelpers::SignalData<void(const QSize &, KWayland::Client::XdgShellSurface::States, quint32)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::UInt, 8 },
        }}),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void(const QSize &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgShellSurface, qt_meta_tag_ZN8KWayland6Client15XdgShellSurfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::XdgShellSurface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client15XdgShellSurfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client15XdgShellSurfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client15XdgShellSurfaceE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::XdgShellSurface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgShellSurface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->closeRequested(); break;
        case 1: _t->configureRequested((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KWayland::Client::XdgShellSurface::States>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[3]))); break;
        case 2: _t->sizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWayland::Client::XdgShellSurface::States >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XdgShellSurface::*)()>(_a, &XdgShellSurface::closeRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (XdgShellSurface::*)(const QSize & , KWayland::Client::XdgShellSurface::States , quint32 )>(_a, &XdgShellSurface::configureRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (XdgShellSurface::*)(const QSize & )>(_a, &XdgShellSurface::sizeChanged, 2))
            return;
    }
}

const QMetaObject *KWayland::Client::XdgShellSurface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::XdgShellSurface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client15XdgShellSurfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::XdgShellSurface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::XdgShellSurface::closeRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWayland::Client::XdgShellSurface::configureRequested(const QSize & _t1, KWayland::Client::XdgShellSurface::States _t2, quint32 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void KWayland::Client::XdgShellSurface::sizeChanged(const QSize & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client13XdgShellPopupE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::XdgShellPopup::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client13XdgShellPopupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::XdgShellPopup",
        "popupDone",
        "",
        "configureRequested",
        "QRect",
        "relativePosition",
        "serial"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'popupDone'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configureRequested'
        QtMocHelpers::SignalData<void(const QRect &, quint32)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::UInt, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgShellPopup, qt_meta_tag_ZN8KWayland6Client13XdgShellPopupE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::XdgShellPopup::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client13XdgShellPopupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client13XdgShellPopupE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client13XdgShellPopupE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::XdgShellPopup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgShellPopup *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->popupDone(); break;
        case 1: _t->configureRequested((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XdgShellPopup::*)()>(_a, &XdgShellPopup::popupDone, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (XdgShellPopup::*)(const QRect & , quint32 )>(_a, &XdgShellPopup::configureRequested, 1))
            return;
    }
}

const QMetaObject *KWayland::Client::XdgShellPopup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::XdgShellPopup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client13XdgShellPopupE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::XdgShellPopup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::XdgShellPopup::popupDone()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWayland::Client::XdgShellPopup::configureRequested(const QRect & _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client14XdgShellStableE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::XdgShellStable::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client14XdgShellStableE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::XdgShellStable"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgShellStable, qt_meta_tag_ZN8KWayland6Client14XdgShellStableE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::XdgShellStable::staticMetaObject = { {
    QMetaObject::SuperData::link<XdgShell::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client14XdgShellStableE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client14XdgShellStableE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client14XdgShellStableE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::XdgShellStable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgShellStable *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KWayland::Client::XdgShellStable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::XdgShellStable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client14XdgShellStableE_t>.strings))
        return static_cast<void*>(this);
    return XdgShell::qt_metacast(_clname);
}

int KWayland::Client::XdgShellStable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgShell::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client17XdgTopLevelStableE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::XdgTopLevelStable::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client17XdgTopLevelStableE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::XdgTopLevelStable"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgTopLevelStable, qt_meta_tag_ZN8KWayland6Client17XdgTopLevelStableE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::XdgTopLevelStable::staticMetaObject = { {
    QMetaObject::SuperData::link<XdgShellSurface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client17XdgTopLevelStableE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client17XdgTopLevelStableE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client17XdgTopLevelStableE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::XdgTopLevelStable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgTopLevelStable *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KWayland::Client::XdgTopLevelStable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::XdgTopLevelStable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client17XdgTopLevelStableE_t>.strings))
        return static_cast<void*>(this);
    return XdgShellSurface::qt_metacast(_clname);
}

int KWayland::Client::XdgTopLevelStable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgShellSurface::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
